﻿$ErrorActionPreference = 'Stop';

$packageName= 'codeslice'
$toolsDir   = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$url        = 'https://www.pragmaticworks.com/Downloads/CodeSlice/BETA_CodeSlice_2016.3.1.428.vsix'

$packageArgs = @{
  packageName   = $packageName
  unzipLocation = $toolsDir
  fileType      = "MSU"
  url           = $url

  silentArgs    = "/qn /norestart /l*v `"$env:TEMP\chocolatey\$($packageName)\$($packageName).MsiInstall.log`""
  validExitCodes= @(0, 3010, 1641)

  softwareName  = "codeslice*"
}

Function Test-VsRegistry($registryPath, $registryProperty)
{
    $result = Get-ItemProperty $registryPath $registryProperty -ErrorAction SilentlyContinue
    
    if (($result -ne $null) -and ($result.InstallDir -ne $null) -and ($result.InstallDir.Length -gt 0))
    {
        return $true
    }

    return $false
}

$isInstallCodeSlice = $false
$vs2012 = $false
$vs2013 = $false

if ([IntPtr]::size -eq 8)
{
    $vs2012 = Test-VsRegistry("HKLM:\Software\WOW6432NODE\Microsoft\VisualStudio\11.0", "InstallDir")
    $vs2013 = Test-VsRegistry("HKLM:\Software\WOW6432NODE\Microsoft\VisualStudio\12.0", "InstallDir")

    if (($vs2012 -eq $false) -and 
        ($vs2013 -eq $false))
    {
        $isInstallCodeSlice = $false
    }
    else
    {
        $isInstallCodeSlice = $true
    }
}
else
{
    $vs2012 = Test-VsRegistry("HKLM:\Software\Microsoft\VisualStudio\11.0", "InstallDir")
    $vs2013 = Test-VsRegistry("HKLM:\Software\Microsoft\VisualStudio\12.0", "InstallDir")

    if (($vs2012 -eq $false) -and 
        ($vs2013 -eq $false))
    {
        $isInstallCodeSlice = $false
    }
    else
    {
        $isInstallCodeSlice = $true
    }
}

if ($isInstallCodeSlice -eq $true)
{
    Install-ChocolateyVsixPackage $packageName $url
}
else
{
    throw "CodeSlice requires Visual Studio 2012 or 2013."
}
